#
# spec file for package python3-veusz
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define appname veusz
%define         X_display         ":98"
%{?_sip_api:Requires: sip-api(%{_sip_api_major}) >= %{_sip_api}}
Name:           python3-veusz
Version:        1.24
Release:        2.1
Summary:        Scientific plotting library for Python
License:        GPL-2.0+ and Python-2.0
Group:          Productivity/Scientific/Other
# The entire source code is GPL-2.0+ except helpers/src/_nc_cntr.c which is Python-2.0
Url:            http://home.gna.org/veusz/
Source0:        http://download.gna.org/veusz/veusz-%{version}.tar.gz
Source3:        veusz_256.png
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
BuildRequires:  python3-devel
BuildRequires:  python3-h5py
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-qt4-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-sip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-server
Requires:       python3-h5py
Requires:       python3-numpy
Requires:       python3-qt4
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
Recommends:     %{appname}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with errors, keys, labels, stacked plots,
multiple plots, contours, shapes and fitting data.

%package -n %{appname}
Summary:        GUI scientific plotting package
Group:          Productivity/Scientific/Other
Requires:       %{name} = %{version}
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Obsoletes:      veusz3 <= 1.24
Provides:       veusz3 = %{version}

%description -n %{appname}
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with errors, keys, labels, stacked plots,
multiple plots, contours, shapes and fitting data.

%prep
%setup -q -n veusz-%{version}
find -name \*~ | xargs rm -f

%build
CFLAGS="%{optflags}"
python3 setup.py build

%install
python3 setup.py install -O1 --skip-build --prefix="%{_prefix}" \
                                               --root=%{buildroot}

# Install .desktop, mime and appdata files from upstream tarball
install -Dm0644 support/veusz.appdata.xml %{buildroot}%{_datadir}/appdata/%{appname}.appdata.xml
install -Dm0644 support/veusz.xml %{buildroot}/%{_datadir}/mime/packages/%{appname}.xml
desktop-file-install -m 0644 \
  --dir=%{buildroot}/%{_datadir}/applications/ \
  --add-category=2DGraphics \
  support/%{appname}.desktop

# move icon files to /usr/share/pixmaps/veusz
mkdir -p %{buildroot}%{_datadir}/pixmaps/%{appname}
mv %{buildroot}%{python3_sitearch}/veusz/icons/*.png \
        %{buildroot}%{_datadir}/pixmaps/%{appname}
mv %{buildroot}%{python3_sitearch}/veusz/icons/*.svg \
        %{buildroot}%{_datadir}/pixmaps/%{appname}
for i in `ls %{buildroot}%{_datadir}/pixmaps/%{appname}/`
do
  ln -s  %{_datadir}/pixmaps/%{appname}/$i \
          %{buildroot}%{python3_sitearch}/veusz/icons/$i ;
done
# hardlink main veusz icon also into hicolor-icon-theme dir (for desktop file)
install -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/%{appname}/veusz_256.png
for size in 16 32 48 64 128 256; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln %{buildroot}%{_datadir}/pixmaps/%{appname}/veusz_${size}.png ${odir}/%{appname}.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln %{buildroot}%{_datadir}/pixmaps/%{appname}/veusz.svg $odir/%{appname}.svg

# Mark some scripts as executable.
# This isn't really needed, but Veusz includes shebangs in scripts
# so that they can be run when not installed.
# Do this so that the scripts don't need modification.
chmod +x %{buildroot}%{python3_sitearch}/veusz/veusz_main.py
chmod +x %{buildroot}%{python3_sitearch}/veusz/veusz_listen.py

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/%{appname}.1 Documents/%{appname}_listen.1 -m 0644 \
        %{buildroot}%{_mandir}/man1

install -m0644 COPYING %{buildroot}%{python3_sitearch}/veusz/

%fdupes -s %{buildroot}%{python3_sitearch}
%fdupes %{buildroot}%{_datadir}/pixmaps/%{appname}/

%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
sleep 5
PYTHONPATH=%{buildroot}%{python3_sitearch} \
           python3 tests/runselftest.py

# CLEAN-UP __pycache__ DIRS CONTAINING OBJECT FILES LEFT BY %%check WITHOUT THE CORRESPONDING SOURCES
rm -fr %{buildroot}%{python3_sitearch}/veusz/*/__pycache__
rm -fr %{buildroot}%{python3_sitearch}/veusz/__pycache__

%post
update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :
%icon_theme_cache_post

%postun
update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :
%icon_theme_cache_postun

%post -n %{appname}
update-desktop-database %{_datadir}/applications

%postun -n %{appname}
update-desktop-database %{_datadir}/applications

%files
%defattr(-,root,root)
%doc README AUTHORS COPYING ChangeLog
%doc Documents/manual.html
%doc Documents/manimages/
%{python3_sitearch}/veusz-%{version}-py*.egg-info
%{python3_sitearch}/veusz/

%files -n %{appname}
%defattr(-,root,root)
%{_bindir}/%{appname}
%{_bindir}/%{appname}_listen
%{_datadir}/applications/%{appname}.desktop
%{_mandir}/man1/*
%{_datadir}/pixmaps/%{appname}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{appname}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{appname}.*
%{_datadir}/mime/packages/%{appname}.xml

%changelog
* Wed Aug  3 2016 badshah400@gmail.com
- Rename veusz3 to veusz (the GUI application has been dropped
  from the python2 version):
  + Remove all references to veusz3 in spec file.
  + Obsolete and provide veusz3.
* Wed Jul  6 2016 badshah400@gmail.com
- Move all application related files to subpackage veusz3, leaving
  only actualy python modules in the python3-veusz pkg.
- Hardlink icons from pixmaps/veusz3 to hicolor-icon-theme, as
  symlinked icons lead to appstream-builder being unable to
  detect them and vetoes the application consequently.
* Sat May  7 2016 badshah400@gmail.com
- Update to version 1.24:
  + Text labels can now include Python expressions inside %%{{ }}%%
  + Added built-in functions DATE([fmt]), TIME([fmt]), FILENAME()
    and BASENAME() when evaluating expressions, which are useful
    when used in labels
  + Added Python dictionary ENVIRON when evaluating expressions,
    to obtain values from environment variables
  + Added DATA(name, [part]) function to expression environment
    for accessing values from datasets, useful for function
    evaluation or labels
  + Added SETTING(path) function for expression evaluation to
    obtain values of settings
  + Added ESCAPE(text) function to environment, which allows LaTeX
    special characters to be displayed in labels
  + Add fractions and percentages units to polar plot
  + Allow number of spokes to be varied in polar plot
  + Widgets can be clicked holding down shift or ctrl, to add or
    toggle their selection
  + Add K. Moreland's cool-warm colormap (thanks to S. Richardson)
  + Added further green-map, blue-darkred, blue-darkorange,
    brown-blue and blue-orange colormaps from Oregon geography
    dept.
  + Add logarithm and exponential dataset plugins
  + Add Wipe() command to embedding interface to clear document
  + Add File->Reload menu option to reload from saved document
  + Add tooltip to items in FieldWidget showing widget path
  + Bux fixes:
  - Fix transparency with bar plot
  - Use getcwdu() for python2 to avoid bugs combining paths
  - Handle inf/nan when converting to human readable form in plots
  - Fix CreateHistogram on command line without binparams
    parameter
  - Handle empty 2D dataset import with grid at edge enabled
  - Do not allow error bars on imported CSV non-numeric data
  - Handle missing argument in \size
  - For data edit dialog, allow 1D dataset to replace 2D dataset
  - Crash if zoom to be height when height is zero
  - Fix problem with 2D import if error message is in unicode
  - With axis-function widget catch result if greater than 1
    dimension
  - Fix cloning for datasets with / in name
  - Fix crash in embedding if plot window closed while rendering
    in progress
  + Clean up mess (__pycache__ dirs containing python object files
  without corresponding sources) after %%clean.
* Sun Apr  3 2016 badshah400@gmail.com
- Add BuildRequires and Requires on python3-h5py: enables the
  hdf5 data import module in the application.
- Run specfile through "spec-cleaner -m" for cleanup.
* Thu Dec 31 2015 arun@gmx.de
- Update to version 1.23.2:
  * Add data clipping dataset plugin
  * Fix boxplot with manual settings
  * Fix plugin normalize and divide by maximum for new numpy versions
  * Avoid error in 2d data creation
  * Fix problems with unicode characters in plugins in Python 2.x
  * Clip axis to sensible range -1e100->1e100
  * Handle unicode errors from operating system in Veusz scripts
  * Handle unicode errors in error reports
  * Fix crash in \color
* Fri Jun 19 2015 badshah400@gmail.com
- Update to version 1.23.1:
  + Enable compression in exported files.
  + Fix saving histogram datasets.
  + Add option to "thin" error bars plotted.
  + Fix label colour in contour labelling.
  + Remove use of deprecated Qt functions.
  + Fix clone widget tools plugin.
  + Fix EPS/PDF crash with broken axis widget.
  + Do not crash filter plugin if using date datatype.
  + Avoid crashes in normalise, subtract minimum and divide
    maximum plugins.
  + Avoid crash in image widget.
  + Avoid issue in identifying spacing in 1D->2D conversion.
  + Add Gnuplot 2D data import plugin.
  + When loading data from import plugins, provide default values.
  + Remove some deprecated Qt uses.
  + Fix issue when plotting non-plain datasets with nan values.
* Sun Apr 19 2015 badshah400@gmail.com
- Update to version 1.23:
  + Add new export dialog box which can export multiple pages and
    modify the export options.
  + Add new dataset filtering dialog.
  + Add cubehelix() functional colormap.
  + Add -stepN suffix for colormaps to make arbitrary numbers of
    steps.
  + Fix incorrect colors in log images and log color scales.
  + Fix unsafe commands not being run.
  + Fix incorrect use of None in (x,...) pattern.
  + Catch crash if plotting nan/inf value in log space.
  + Fix getData in dataset plugin for dimensions=2
  + Catch error in too large float to date time conversion.
  + Catch disappeared file during import.
  + Index error fixed in pickable.
  + Catch error in data edit dialog if 2d dataset size changes.
  + If root widget is selected with others, do not error on hide.
  + Fix undo for dataset histogram with a single output dataset.
  + Fix error resizing ellipse with a tuple width, height or
    position setting.
  + Only use finite values in histogram.
  + Rewrite Line/FillSet setting controls for internal consistency
    and to fix new style extended fills.
  + Do not crash with log date-time axes.
  + Also ignore non-finite values when fitting with minuit.
  + Avoid syntax error with invalid colormap.
  + Updates to setup.py and desktop files.
  + Recreate dataset now works if dialog hasn't been opened
    already.
  + Restore dock layout when using Python3
  + Fix undo after loading stylesheet/custom definitions.
  + Support unicode example filenames.
  + Clip bezier lines to avoid problems with log axes.
- Drop veusz-python3-naming.patch: if we are going to be
  carrying this, it is better we do it using sed in the specfile
  itself rather than rebase this patch against every version up;
  specfile modifications to take care of name changes.
* Sat Apr 11 2015 badshah400@gmail.com
- Fix symlink creation of icons, so that they actually show up.
- Fix incorrect use of %%icon_theme_cache_post(un) scriptlets
  in post installation scripts.
* Wed Mar  4 2015 toddrme2178@gmail.com
- Correctly use patch
* Mon Mar  2 2015 toddrme2178@gmail.com
- Reorganize files so the python 2 and python 3 versions of the
  package do not conflict
  * Add veusz-python3-naming.patch, which is part of this
- Split gui stuff into veusz3 subpackage per python package naming
  guidelines.
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Sun Oct 19 2014 badshah400@gmail.com
- Update to version 1.22:
  + Add option to ignore white space following delimiters when
    importing CSVs
  + Allow x/yedge and x/ycent to be inverted to change data order
    when import 2D data
  + Rewrite of widget tree internals to fix miscellaneous bugs
  + Optionally use astropy for SAMP
  + Add setting to extend the python import path
  + Add option to select widgets with same name on page
  + Resize rectangular shapes keeping other corners fixed; old
    symmetric resize behaviour is retained if shift is pressed.
* Sat Aug 30 2014 badshah400@gmail.com
- Update to version 1.21.1:
  + Add swap option on keys, swapping symbol and text
  + Bug fixes:
  - Fix missing labels if colorbar out of plot
  - Preserve tags when reloading datasets
  - Handle nan/inf/-inf when as value in UI
  - Remove dependence on pyqtconfig in build system
  - Handle errors properly in 2D CSV read
  - Do not crash if selecting siblings of document widget
  - Fix accidental modification of data by line widget
  - Improve PDF bounding box rounding to prevent chopping near
    edge
  - Fix function plotter in embedding
  - Fix astropy version checking
  - Fix crash for error bar in CSV with blank previous column
- Drop python-veusz-test-disable-contour_labels.patch; patch
  incorporated upstream.
* Mon May  5 2014 badshah400@gmail.com
- Update to version 1.21:
  + Add HDF5 saved document format
  + Add filled curve error bar style
  + Add fill left/right options for point plotter
  + Add filetype filters to import dialog file browser dialog
  + In file completer in import dialog, use selected tab as filter
  + Move code to use PyQt new style signals
  + Add a master color setting for xy point and nonorthpoint plot
  + Line labelling algorithm much improved in contour plots, which
    rotates text to match line angle and avoids label overlaps
  + More accurate axis tick label bounding boxes, allowing rotated
    labels to be placed close together
  + Add reflection and rotation options to vector field widget
  + Switch to scientific notation earlier when showing float
    settings
  + Bug fix:
  - Direction combo did not work in import dialog
  - Saving text datasets did not work in Python3
  - Fix partial dataset evaluation issue when loading documents
  - 2D non-regular pixel spaced images give error if clipped in
    y
  - Handle Unicode quoted characters in simple text data files
  - xcent/ycent in Dataset2D import plugins were ignored
  - promote_tab broken for import plugins
  - Full screen view when all pages are deleted
  - Crash with empty dataset and boxplot widget
  - Fix copy and paste of datasets
  - Python 3 resizing axis bug
  - Crash if picking/zooming on document with no pages
  - Crash if reediting histogram dataset with blank output entry
  - Use end of text formatting string beyond format specifier
  - When writing SVG text as text, use xml:space="preserve" to
    avoid missing whitespace
  - Embedding socket issue on Python 3.4+
- Add veusz-test-disable-contour_labels.patch to disable a
  test that unnecessarily causes build failures; patch came from
  upstream.
* Wed Feb 12 2014 badshah400@gmail.com
- Update to version 1.20.1:
  + Include free-desktop appdata, MIME and desktop files
  + When plotting xy widget filled error regions, plot line on top
  + Bug-fixes:
  - Fix embedding interface startup problem in 1.20
  - Additional embedding interface fixes for Python 3
  - Fix crash in tutorial if flashing widget deleted
  - Fix polar plot crash with reverse minumum and maximum radii
  - Fix crash when changing range of broken axes interactively
  - Fix object deletion crash in setting menu
  - Check output dataset is not same as an input for histograms
  - Fix for compilation on Qt 4.6
  - Catch socket errors on embed client
  - Fixes for formatting strings, including fixes for arguments
    of the extended %%Vg format and properly supporting %%%%
  - When restoring window position, do not restore offscreen
- Packaging changes:
  + Drop macros for EOL openSUSE versions in spec file
  + Upstream bundles desktop and MIME files, install these
    instead of external desktop and MIME files (use
    desktop-file-install to add categories to .desktop file)
  + Also package appdata bundled with upstream tarball.
* Fri Jan 17 2014 badshah400@gmail.com
- Update to version 1.20:
  + Add HDF5 file data import
  + Allow expressions to be edited for linked 2D datasets
  + Add support for 2D datasets with irregular gridpoints
  + Add 2D data CSV import
  + Allow safe renaming of linked datasets
  + Support importing text from FITS files
  + Bug fixes:
  - When capturing data from a file/named pipe, do not stop
    when no more data are available
  - Fixes mangling of text in saved files using Windows binary
  - Fix encoding for standard file import
  - Fix FITS import for python3
* Fri Nov 29 2013 badshah400@gmail.com
- Update to 1.19.1:
  + Add option to disable scaling of marker border with point
    scaling
  + Implement label at-minimum/at-maximum for ternary plot
  + Add border and background fill settings for text label widget
  + Enable FITS support with astropy
  + Bug fixes:
  - Fix broken drag and drop in documents
  - Fix deleted C/C++ object crash when using undo and in
    tutorial
  - Fix compilation in MSVC for Python 3
  - Remove warning/error in compilation in gcc in SUSE
  - Add Python version classifiers
  - Fix document icons in Windows binary
  - Error bars can be plotted incorrectly for histogrammed data
- Drop python3-veusz-fix-no-return-in-non-void-function.patch;
  better fix incorporated by upstream.
* Mon Nov 18 2013 badshah400@gmail.com
- Initial build with python 3.
